# Plover Better RTF

Plover plugin for better RTF dictionary handling. Powered by
[rtfcre](https://github.com/sammdot/rtfcre).

Unfortunately, I can't find a way to override Plover's built-in RTF dictionary
plugin, so for now your RTF dictionaries will have to be named `.rtfcre` if you
want to use this plugin.
